@@ -1,7 +1,8 @@
-import { Component } from "@angular/core";
+import { Component } from "@angular/core"
 
 @Component({
     selector: "user-admin",
     templateUrl: "user.component.html",
 })
-export class UserComponent {}
+export class UserComponent {
+}
