@@ -1,10 +1,12 @@
 import logging
 
 from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
-from peek_core_user._private.client.TupleActionProcessorProxy import \
-    makeTupleActionProcessorProxy
-from peek_core_user._private.client.TupleDataObservableProxy import \
-    makeTupleDataObservableProxy
+from peek_core_user._private.client.TupleActionProcessorProxy import (
+    makeTupleActionProcessorProxy,
+)
+from peek_core_user._private.client.TupleDataObservableProxy import (
+    makeTupleDataObservableProxy,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -18,12 +20,15 @@ class PluginClientEntryHook(PluginClientEntryHookABC):
     def load(self):
         # Load the tuples, so that Payload can parse them
         from peek_core_user._private.tuples import loadPrivateTuples
+
         loadPrivateTuples()
 
         from peek_core_user._private.storage.DeclarativeBase import loadStorageTuples
+
         loadStorageTuples()
 
         from peek_core_user.tuples import loadPublicTuples
+
         loadPublicTuples()
 
         logger.debug("loaded")
@@ -42,4 +47,3 @@ class PluginClientEntryHook(PluginClientEntryHookABC):
 
     def unload(self):
         logger.debug("unloaded")
-
